@@ -1,12 +1,12 @@
 /* GNU Chess 5.0 - book.h - book symbolic definitions
-   Copyright (c) 1999 Free Software Foundation, Inc.
+   Copyright (c) 1999-2002 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs 
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
 
    GNU Chess is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Chess is distributed in the hope that it will be useful,
@@ -25,8 +25,16 @@
 */
 #define BOOKSRC "book.src"
 
-/* The book which BookQuery() uses */
-#define BOOKBIN "book.dat"
+/*
+ * BookQuery() tries the following filenames in order to find
+ * a valid opening book. The array must be NULL-terminated.
+ */
+static char const * bookbin[] = {
+   "book.dat",
+   "/usr/share/games/gnuchess/book.dat",
+   "/usr/lib/games/gnuchess/book.dat",
+   NULL
+};
 
 /* The book which BookBuilder() uses */
 #define BOOKRUN "book.dat"
