@@ -6,7 +6,7 @@
 
    GNU Chess is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Chess is distributed in the hope that it will be useful,
@@ -156,12 +156,10 @@ typedef struct
 #define SET(a,b)                     \
   do {                               \
     (a) |= (b);                      \
-    dbg_printf("Set   0x%x\n", (b)); \
   } while (0)
 #define CLEAR(a,b)                   \
   do {                               \
     (a) &= ~(b);                     \
-    dbg_printf("Clear 0x%x\n", (b)); \
   } while (0)
 
 /* Draw score can be used to penalise draws if desired */
@@ -374,7 +372,7 @@ extern int RealGameCnt;
 extern short RealSide;
 extern int GameCnt;
 extern int computer;
-extern unsigned int flags;
+extern volatile unsigned int flags;
 extern unsigned int preanalyze_flags;
 extern Board board;
 extern int cboard[64];
@@ -745,7 +743,7 @@ void wait_for_input(void);
  * Input routine, initialized to one of the specific
  * input routines. The given argument is the prompt.
  */
-void (*getline) (char *);
+void (*get_line) (char *);
 
 #define MAXSTR 128
 extern char inputstr[MAXSTR];
@@ -753,6 +751,9 @@ extern char inputstr[MAXSTR];
 /* Input parser */
 void parse_input(void);
 
+/* Check Board to avoid analysis of incorrectly input positions */
+void check_board(void);
+
 /* Pondering */
 void ponder(void);
 
@@ -787,6 +788,7 @@ void cmd_list(void);
 void cmd_load(void);
 void cmd_manual(void);
 void cmd_movenow(void);
+void cmd_memory(void);
 void cmd_name(void);
 void cmd_new(void);
 void cmd_nopost(void);
@@ -833,29 +835,4 @@ unsigned char nbits (BitBoard);
 # include "inlines.h"
 #endif
 
-/* More elaborate debugging output to logfile */
-
-/* All the following functions are no-ops if DEBUG is not defined */
-
-/*
- * dbg_open() can be called with NULL as argument, using a default
- * filename, defined in debug.c, for the debug log. Otherwise the
- * argument is the filename. If dbg_open() fails or is not called at
- * all, debugging output goes to stderr by default.
- */
-int dbg_open(const char *name);
-
-/* Same format rules as printf() */
-int dbg_printf(const char *fmt, ...);
-
-/* Closes the debugging log, if it is not stderr */
-int dbg_close(void);
-
-# ifdef DEBUG
-#  include <assert.h>
-#  define ASSERT(x) assert(x)
-# else
-#  define ASSERT(x)
-# endif
-
 #endif /* !COMMON_H */
