@@ -6,7 +6,7 @@
 
    GNU Chess is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Chess is distributed in the hope that it will be useful,
@@ -53,12 +53,12 @@ static int PawnSq[2][64] =
   -2, -2, -2,  6,  6, -2, -2, -2,
    0,  0,  0, 25, 25,  0,  0,  0,
    2,  2, 12, 16, 16, 12,  2,  2,
-   4,  8, 12, 16, 16, 12,  4,  4,
-   4,  8, 12, 16, 16, 12,  4,  4,
+   4,  4, 12, 16, 16, 12,  4,  4,
+   4,  4, 12, 16, 16, 12,  4,  4,
    0,  0,  0,  0,  0,  0,  0,  0},
 {  0,  0,  0,  0,  0,  0,  0,  0,
-   4,  8, 12, 16, 16, 12,  4,  4,
-   4,  8, 12, 16, 16, 12,  4,  4,
+   4,  4, 12, 16, 16, 12,  4,  4,
+   4,  4, 12, 16, 16, 12,  4,  4,
    2,  2, 12, 16, 16, 12,  2,  2,
    0,  0,  0, 25, 25,  0,  0,  0,
   -2, -2, -2,  6,  6, -2, -2, -2,
@@ -115,8 +115,12 @@ int ScoreP (short side)
    BitBoard c, t, p, blocker, *e;
    PawnSlot *ptable;
 
-   if (board.b[side][pawn] == NULLBITBOARD)
+   if (board.b[side][pawn] == NULLBITBOARD){
+	/* Reset these in case last pawn was captured */
+      passed[side] = NULLBITBOARD;
+      weaked[side] = NULLBITBOARD;
       return (0);
+   }
    xside = 1^side;
    EnemyKing = board.king[xside];
    p = board.b[xside][pawn];
@@ -155,7 +159,7 @@ int ScoreP (short side)
 
       /*  Backward pawns */
       backward = false;
-    /*   i = sq + (side == white ? 8 : -8); */
+    
       if ( side == white ) {
  	 i = sq + 8;  }
       else {
@@ -171,7 +175,7 @@ int ScoreP (short side)
       }
       if (!backward && (BitPosArray[sq] & brank7[xside]))
       {
-         i1 = 1;
+         i1 = i;
          i = i + (side == white ? 8 : -8);
          if (!(PassedPawnMask[xside][i] & ~FileBit[ROW(i1)] & c))
          {
@@ -213,30 +217,6 @@ int ScoreP (short side)
       }
    }
 
-
-  if (computerplays == side) {
-
-    /* Penalize having eight pawns */
-    if (nbits(board.b[computerplays][pawn]) == 8)
-        s += EIGHT_PAWNS;
-
-    /* Detect stonewall formation in enemy */
-    if (nbits(stonewall[xside] & board.b[xside][pawn]) == 3)
-      s += STONEWALL;
-
-    /* Locked pawns */
-    n = 0;
-    if (side == white)
-      n = nbits((c >> 8) & board.b[xside][pawn] &
-               boxes[1]);
-    else
-      n = nbits((c << 8) & board.b[xside][pawn] &
-               boxes[1]);
-    if (n > 1)
-      s += n * LOCKEDPAWNS;
-  }
-
-
    /* Save the score into the pawn hash table */ 
    ptable->pkey = KEY(PawnHashKey);
    ptable->passed = passed[side];
@@ -283,7 +263,7 @@ phase2:
       n2 = RANK(board.king[xside]);
       for (i = 0; i <= 6; i++)
       {
-	 if (t & FileBit[i] && t & FileBit[i+1] && (n1 < i-1 || n1 > i+1 ||
+	 if (t & FileBit[i] && t & FileBit[i+1] && (n1 < i || n1 > i+1 ||
 		(side == white && n2 < 4) || (side == black && n2 > 3)))
             s += CONNECTEDPP;
       }
@@ -622,7 +602,7 @@ int ScoreR (short side)
 	 else if (Ray[sq][4] & passed[white])
             s1 += ROOKINFRONTPP;
       }
-      if (FileBit[fyle] & passed[black] & brank58[black])
+      if (phase > 6 && (FileBit[fyle] & passed[black] & brank58[black]))
       {
 	 if (nbits (Ray[sq][4] & passed[black]) == 1)
 	    s1 += ROOKBEHINDPP;
@@ -681,14 +661,6 @@ int ScoreQ (short side)
    
    s = s1 = 0;
 
-   /* Try to keep our queen on the board for attacking purposes. */
-   if (board.b[side][queen] == NULLBITBOARD) {
-       if (side == computer) {
-         s += QUEEN_NOT_PRESENT;
-       }
-       return(s);
-    }                                                                           
-
    xside = 1 ^ side;
    c = board.b[side][queen];
    EnemyKing = board.king[xside];
@@ -777,11 +749,14 @@ int ScoreK (short side)
       /* After castling kingside, reward having all 3 pawns in front but not if
 	 there is a threatening pawn. This permits the freeing move F3/F6. */
 	 
-      if (side == white)
+      if (side == white && rank == 0) {
         n = nbits (MoveArray[king][sq] & board.b[side][pawn] & RankBit[rank+1]);
-      else
+        s += pawncover[n];
+      }
+      if (side == black && rank == 7) {
         n = nbits (MoveArray[king][sq] & board.b[side][pawn] & RankBit[rank-1]);
-      s += pawncover[n];
+        s += pawncover[n];
+      }
 
       /* Penalize compromised wing pawn formations prior to castle. */
       if (!board.castled[side]) {
@@ -819,15 +794,6 @@ int ScoreK (short side)
 	if (n != -1) s += pawncover[n];
       }
 
-      if (side == computer && file >= F_FILE && 
-		!(FileBit[G_FILE] & board.b[side][pawn]))
-      {
-         if (side == white && cboard[F2] == pawn)
-            s += GOPEN;
-         else if (side == black && cboard[F7] == pawn)
-            s += GOPEN;
-      }
-
       /* No friendly pawns on this king file */
       if (!(FileBit[file] & board.b[side][pawn]))
          s += KINGOPENFILE;
@@ -885,37 +851,6 @@ int ScoreK (short side)
 	  }
 	}
       }
-      if (side == computer) {
-
-	/* Stock piece sacrifice on h file */
-
-	if (file >= E_FILE && board.b[xside][queen] && board.b[xside][rook] &&
-	    !((board.b[side][pawn]|board.b[xside][pawn]) & FileBit[7]))
-         s += HOPEN;
-	
-	/* King trapping rook */
-        if (side == white) {
-	  if (file > E_FILE) {
-	    if (board.b[side][rook]&mask_kr_trapped_w[H_FILE-file]) {
-		s += ROOKTRAPPED;
-	    }
-	  } else if (file < D_FILE) {
-	    if (board.b[side][rook]&mask_qr_trapped_w[file]) {
-		s += ROOKTRAPPED;
-	    }
-	  }
-	} else {
-	  if (file > E_FILE) {
-	    if (board.b[side][rook]&mask_kr_trapped_b[H_FILE-file]) {
-		s += ROOKTRAPPED;
-	    }
-	  } else if (file < D_FILE) {
-	    if (board.b[side][rook]&mask_qr_trapped_b[file]) {
-		s += ROOKTRAPPED;
-	    }
-	  }
-	}
-      }
 
       /* Don't give fianchetto target for advanced pawns */
       if (file > E_FILE && ROW(board.king[xside]) < D_FILE) {
@@ -962,10 +897,8 @@ int ScoreK (short side)
          CLEARBIT (b, sq1);
 	 if (BitPosArray[sq1] & board.b[white][pawn])
             s -= distance[sq][sq1+8] * 10 - 5;
-	 else if (BitPosArray[sq1] & board.b[white][pawn])
+	 else if (BitPosArray[sq1] & board.b[black][pawn])
             s -= distance[sq][sq1-8] * 10 - 5;
-         else
-	    s -= distance[sq][sq1] - 5;
       }
 
       /* Attack on weak opponent pawns */
@@ -1214,19 +1147,16 @@ int ScoreDev (short side)
  *
  ***************************************************************************/
 {
-   int s = 0;
-   int xside;
+   int s;
    int sq;
    BitBoard c;
 
-   xside = 1 ^ side;
-
    /* Calculate whether we are developed */
    c = (board.b[side][knight] & nn[side]) | (board.b[side][bishop] & bb[side]);
-   s += nbits(c) * -8;
+   s = nbits(c) * -8;
 
-   /* If we are castled or beyond the 10th move, no more ScoreDev */
-   if (board.castled[side] || GameCnt/2+1 >= 20)
+   /* If we are castled or beyond the 20th move, no more ScoreDev */
+   if (board.castled[side] || GameCnt >= 38)
       return (s);
 
    s += NOTCASTLED;
@@ -1264,7 +1194,8 @@ int ScoreDev (short side)
    }
 
    /* Discourage any wing pawn moves */
-   c = board.b[side][pawn] & (FileBit[0]|FileBit[1]|FileBit[6]|FileBit[7]);
+/*   c = board.b[side][pawn] & (FileBit[0]|FileBit[1]|FileBit[6]|FileBit[7]); */
+   c = board.b[side][pawn] & ULL(0xc3c3c3c3c3c3c3c3);
    while (c) {
      sq = leadz(c);
      CLEARBIT(c, sq);
@@ -1273,7 +1204,8 @@ int ScoreDev (short side)
    }
 
    /* Discourage any repeat center pawn moves */
-   c = board.b[side][pawn] & (FileBit[2]|FileBit[3]|FileBit[4]|FileBit[5]);
+/*   c = board.b[side][pawn] & (FileBit[2]|FileBit[3]|FileBit[4]|FileBit[5]); */
+   c = board.b[side][pawn] & ULL(0x3c3c3c3c3c3c3c3c);
    while (c) {
      sq = leadz(c);
      CLEARBIT(c, sq);
