@@ -6,7 +6,7 @@
 
    GNU Chess is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Chess is distributed in the hope that it will be useful,
@@ -32,6 +32,7 @@
 
 #include "common.h"
 #include "version.h"
+#include "lexpgn.h"
 
 void Initialize (void)
 /**************************************************************************
@@ -644,6 +645,16 @@ void InitVars (void)
    board.material[white] = board.material[black] =
       board.pmaterial[white] + 8*ValueP;
 
+   /* Initialize pgn values */
+   initial_comments = NULL;
+   /* Reset values; doing this again will cause a trivial memory leak
+    * when reloading PGN files as games, but it's not worth fixing. */
+   pgn_event = pgn_site =
+   pgn_date = pgn_round = pgn_white = pgn_black =
+   pgn_whiteELO = pgn_blackELO = pgn_result =
+   pgn_othertags = NULL; 
+
+
    UpdateFriends ();
    UpdateCBoard ();
    UpdateMvboard ();
@@ -672,22 +683,9 @@ void InitVars (void)
    phase = PHASE;
 
 /*  Calculate the ttable hashmask & pawntable hashmask */
-   i = HASHSLOTS;
-   TTHashMask = 0;
-   while ((i>>=1) > 0)
-   {
-      TTHashMask <<= 1;
-      TTHashMask |= 1;
-   }
-   HashSize = TTHashMask + 1; 
-   i = PAWNSLOTS;
-   PHashMask = 0;
-   while ((i>>=1) > 0)
-   {
-      PHashMask <<= 1;
-      PHashMask |= 1;
-   }
-
+   if ( HashSize == 0 )
+     CalcHashSize(HashSize);
+     
    signal (SIGINT, EndSearch);
 
    nmovesfrombook = 0;
@@ -728,53 +726,54 @@ void InitHashCode (void)
 
 void InitHashTable (void)
 /****************************************************************************
- *
- *  Allocate memory for our transposition tables.  By default, the
- *  transposition table will have 16K entries; 8K for each color.
- *  Add code to allocated memory for pawn table as well.
- *
- ****************************************************************************/
+  *
+  *  Allocate memory for our transposition tables.  By default, the
+  *  transposition table will have 16K entries; 8K for each color.
+  *  Add code to allocated memory for pawn table as well.
+  *
+  ****************************************************************************/
 {
-   unsigned int size;
- 
-   /* One can not use realloc() here, it screws up error handling */
-   do {
-     free(HashTab[0]);
-     free(HashTab[1]);
-     HashTab[0] = malloc (HashSize * sizeof (HashSlot));
-     HashTab[1] = malloc (HashSize * sizeof (HashSlot));
-     if (HashTab[0] == NULL || HashTab[1] == NULL) {
-        printf ("Not enough memory for transposition table, trying again.\n");
-        HashSize >>= 1;
-	TTHashMask >>= 1;
-	if (HashSize == 0) {
-	  fprintf(stderr, "Memory exhausted, goodbye, my friend.\n");
-	  exit(EXIT_FAILURE);
-	}
-	continue;
-     }
-   } while (0);
-   size = (HashSize * 2 * sizeof (HashSlot)) >> 10;
-   if (!(flags & XBOARD)) {
-     printf ("Transposition table:  Entries=%dK Size=%dK\n", 
-             HashSize>>10, size);
-   }
-
-   /*
-    * Here realloc() is O.K., though not very useful, because PAWNSLOTS
-    * is constant anyway.
-    */
-   PawnTab[0] = (PawnSlot *) realloc (PawnTab[0], PAWNSLOTS * sizeof (PawnSlot));
-   PawnTab[1] = (PawnSlot *) realloc (PawnTab[1], PAWNSLOTS * sizeof (PawnSlot));
-   if (PawnTab[0] == NULL || PawnTab[1] == NULL) {
-      printf ("Not enough memory for pawn table, goodbye.\n");
-      exit(EXIT_FAILURE);
-   } else {
-      size = (PAWNSLOTS * 2 * sizeof (PawnSlot)) >> 10;
-      if (!(flags & XBOARD))
-	printf ("Pawn hash table: Entries=%dK Size=%dK\n",
-		PAWNSLOTS >> 10, size);
-   }
+    unsigned int size;
+    unsigned int allocating = 1;
+    /* One can not use realloc() here, it screws up error handling */
+    do {
+      free(HashTab[0]);
+      free(HashTab[1]);
+      HashTab[0] = malloc (HashSize * sizeof (HashSlot));
+      HashTab[1] = malloc (HashSize * sizeof (HashSlot));
+      if (HashTab[0] == NULL || HashTab[1] == NULL) {
+         printf ("Not enough memory for transposition table, trying again.\n");
+         if (HashSize == HASHSLOTS) {
+           fprintf(stderr, "Memory exhausted, goodbye, my friend.\n");
+           exit(EXIT_FAILURE);
+         }
+         CalcHashSize(HashSize>>1);
+      }
+      else
+         allocating = 0;
+    } while (allocating);
+    size = (HashSize * 2 * sizeof (HashSlot)) >> 10;
+    if (!(flags & XBOARD)) {
+      printf ("Transposition table:  Entries=%dK Size=%dK\n",
+              HashSize>>10, size);
+    }
+    /*
+     * Here realloc() is O.K., though not very useful, because PAWNSLOTS
+     * is constant anyway.
+     */
+    PawnTab[0] = (PawnSlot *) realloc (PawnTab[0], PAWNSLOTS * sizeof 
+(PawnSlot));
+    PawnTab[1] = (PawnSlot *) realloc (PawnTab[1], PAWNSLOTS * sizeof 
+(PawnSlot));
+    if (PawnTab[0] == NULL || PawnTab[1] == NULL) {
+       printf ("Not enough memory for pawn table, goodbye.\n");
+       exit(EXIT_FAILURE);
+    } else {
+       size = (PAWNSLOTS * 2 * sizeof (PawnSlot)) >> 10;
+       if (!(flags & XBOARD))
+         printf ("Pawn hash table: Entries=%dK Size=%dK\n",
+                 PAWNSLOTS >> 10, size);
+    }
 }
 
 
@@ -786,6 +785,7 @@ void NewPosition (void)
  ****************************************************************************/
 {
    CLEAR (flags, ENDED);
+   check_board();
    Game50 = 0;
    RealGameCnt = GameCnt = -1;
    Game[0].hashkey = HashKey;
