@@ -6,7 +6,7 @@
 
    GNU Chess is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Chess is distributed in the hope that it will be useful,
@@ -74,7 +74,7 @@ int GameCnt;
 int RealGameCnt;
 short RealSide;
 int computer;
-unsigned int flags;
+volatile unsigned int flags;
 unsigned int preanalyze_flags;
 int cboard[64];
 int Mvboard[64];
@@ -143,9 +143,6 @@ int castled[2];
 int hunged[2];
 int phase;
 int Hashmv[MAXPLYDEPTH];
-int Debugmv[MAXPLYDEPTH];
-short Debugmvl;
-short Debugline;
 short RootPieces;
 short RootPawns;
 short RootMaterial;
@@ -161,7 +158,7 @@ short pscore[64];
 short bookmode;
 short bookfirstlast;
 
-const char *progname;
+char *progname;
 FILE *ofp;
 int myrating, opprating, suddendeath, TCionc;
 char name[50];
@@ -301,20 +298,23 @@ int main (int argc, char *argv[])
    */
  
   int c;
-  int opt_help = 0, opt_version = 0, opt_post = 0, opt_xboard = 0, opt_hash = 0;
+  int opt_help = 0, opt_version = 0, opt_post = 0, opt_xboard = 0, opt_hash = 0, opt_memory = 0, opt_easy = 0, opt_manual = 0;
   char *endptr;
 
-  progname = argv[0]; // Save in global for cmd_usage
+  progname = argv[0]; /* Save in global for cmd_usage */
 
   while (1)
   {
     static struct option long_options[] =
     {
         {"hashsize", 1, 0, 's'},
+        {"memory", 1, 0, 'M'},
         {"version", 0, 0, 'v'},
         {"help", 0, 0, 'h'},
         {"xboard", 0, 0, 'x'},
         {"post", 0, 0, 'p'},
+        {"easy", 0, 0, 'e'},
+        {"manual", 0, 0, 'm'},
         {0, 0, 0, 0}
     };
  
@@ -322,7 +322,7 @@ int main (int argc, char *argv[])
 
     int option_index = 0;
  
-    c = getopt_long (argc, argv, "hpvxs:",
+    c = getopt_long (argc, argv, "ehmpvxs:M:",
              long_options, &option_index);
  
     /* Detect the end of the options. */
@@ -348,26 +348,44 @@ int main (int argc, char *argv[])
      case 'p':
        opt_post = 1;
        break;
+     case 'e':
+       opt_easy = 1;
+       break;
+     case 'm':
+       opt_manual = 1;
+       break;
      case 's':    
-       if  ( optarg == NULL ){ // we have error such as two -s
+       if  ( optarg == NULL ){ /* we have error such as two -s */
          opt_help = 1;
          break;
        }
-       errno = 0; // zero error indicator
+       errno = 0; /* zero error indicator */
        opt_hash = strtol (optarg, &endptr, 10);
        if ( errno != 0 || *endptr != '\0' ){
          printf("Hashsize out of Range or Invalid\n");
          return(1);
        }
        break;
-     case '?': // On error give help - getopt does a basic message.
+     case 'M':    
+       if  ( optarg == NULL ){ /* we have error such as two -s */
+         opt_help = 1;
+         break;
+       }
+       errno = 0; /* zero error indicator */
+       opt_memory = strtol (optarg, &endptr, 10);
+       if ( errno != 0 || *endptr != '\0' ){
+         printf("Memory size invalid\n");
+         return(1);
+       }
+       break;
+     case '?': /* On error give help - getopt does a basic message. */
        opt_help = 1;
        break;
      default:
        puts ("Option Processing Failed\n");
        abort();
      }
-  } // end of getopt_long style parsing
+  } /* end of getopt_long style parsing */
 
   /* Initialize random number generator */
   srand((unsigned int) time(NULL));
@@ -392,7 +410,8 @@ int main (int argc, char *argv[])
 	SET (flags, XBOARD);
   if (opt_post == 1)
 	SET (flags, POST);	
-  
+  if (opt_manual ==1)
+	SET (flags, MANUAL);
   cmd_version();
   
   /* If the version option was specified we can exit here */
@@ -402,31 +421,27 @@ int main (int argc, char *argv[])
   /* If a usage statement is required output it here */
   if (opt_help == 1){
     cmd_usage();
-    return (1); // Maybe an error if due to bad arguments.
+    return (1); /* Maybe an error if due to bad arguments. */
   }
 
-  dbg_open(NULL);
-
-  if ( opt_hash != 0){
-    /* 
-     * This code should be refactored from here, cmd.c, and init.c
-     * into the hashtable allocation. SRW Implementing command lines 
-     * changes.
-     */
-    int i;
-    i = opt_hash;
-    TTHashMask = 0;
-    while ((i >>= 1) > 0) {
-      TTHashMask <<= 1;
-      TTHashMask |= 1;
-    }
-    HashSize = TTHashMask + 1;
-    printf ("Adjusting HashSize to %d slots\n", HashSize); 
+  if (opt_memory != 0 && opt_hash != 0 ){
+    cmd_usage();
+    return (1); /* only one or the other */
   }
+
+  HashSize = 0 ; /* Set HashSize zero */
+  if ( opt_hash != 0)
+    CalcHashSize(opt_hash);
+
+  if ( opt_memory > 0 ){
+    int tablesize=(1048576*opt_memory)/(2*sizeof(HashSlot));
+    CalcHashSize(tablesize);
+  }
+
   Initialize ();
 
-  /* Default to enable pondering */
-  SET (flags, HARD);
+  if ( opt_easy == 0)
+   SET (flags, HARD);
 
   if (argc > 1) {
     for (i = 0; i < argc; i++) {
@@ -442,11 +457,8 @@ int main (int argc, char *argv[])
   bookfirstlast = 3;
 
   while (!(flags & QUIT)) {
-    dbg_printf("Waiting for input...\n");
     wait_for_input();
-    dbg_printf("Parsing input...\n");
     parse_input();
-    dbg_printf("input_status = %d\n", input_status);
     if ((flags & THINK) && !(flags & MANUAL) && !(flags & ENDED)) {
       if (!(flags & XBOARD)) printf("Thinking...\n");
       Iterate ();
@@ -454,9 +466,7 @@ int main (int argc, char *argv[])
     }
     RealGameCnt = GameCnt;
     RealSide = board.side;
-    dbg_printf("Waking up input...\n");
     input_wakeup();
-    dbg_printf("input_status = %d\n", input_status);
     /* Ponder only after first move */
     /* Ponder or (if pondering disabled) just wait for input */
     if ((flags & HARD) && !(flags & QUIT) ) {
@@ -470,6 +480,5 @@ int main (int argc, char *argv[])
   free (HashTab[0]);
   free (HashTab[1]);
 
-  dbg_close();
   return (0);
 }
